@@ -231,7 +231,6 @@ typedef int TickitWindowEventFn(TickitWindow *win, TickitEventType ev, void *inf
 TickitPen *tickit_pen_new(void);
 TickitPen *tickit_pen_new_attrs(TickitPenAttr attr, ...);
 TickitPen *tickit_pen_clone(const TickitPen *orig);
-void       tickit_pen_destroy(TickitPen *pen);
 
 TickitPen *tickit_pen_ref(TickitPen *pen);
 void       tickit_pen_unref(TickitPen *pen);
@@ -315,6 +314,9 @@ TickitTerm *tickit_term_new(void);
 TickitTerm *tickit_term_new_for_termtype(const char *termtype);
 void tickit_term_destroy(TickitTerm *tt);
 
+TickitTerm *tickit_term_ref(TickitTerm *tt);
+void        tickit_term_unref(TickitTerm *tt);
+
 TickitTerm *tickit_term_open_stdio(void);
 
 const char *tickit_term_get_termtype(TickitTerm *tt);
@@ -433,6 +435,9 @@ size_t tickit_string_col2byte(const char *str, int col);
 TickitRenderBuffer *tickit_renderbuffer_new(int lines, int cols);
 void tickit_renderbuffer_destroy(TickitRenderBuffer *rb);
 
+TickitRenderBuffer *tickit_renderbuffer_ref(TickitRenderBuffer *rb);
+void                tickit_renderbuffer_unref(TickitRenderBuffer *rb);
+
 void tickit_renderbuffer_get_size(const TickitRenderBuffer *rb, int *lines, int *cols);
 
 void tickit_renderbuffer_translate(TickitRenderBuffer *rb, int downward, int rightward);
@@ -517,6 +522,9 @@ TickitWindow *tickit_window_root(const TickitWindow *win);
 
 void tickit_window_destroy(TickitWindow *win);
 
+TickitWindow *tickit_window_ref(TickitWindow *win);
+void          tickit_window_unref(TickitWindow *win);
+
 int  tickit_window_bind_event(TickitWindow *win, TickitEventType ev, TickitBindFlags flags,
     TickitWindowEventFn *fn, void *user);
 void tickit_window_unbind_event_id(TickitWindow *win, int id);
