@@ -9,7 +9,7 @@ use strict;
 use warnings;
 
 BEGIN {
-   our $VERSION = '0.58';
+   our $VERSION = '0.59';
 }
 
 use Carp;
@@ -168,18 +168,20 @@ sub new
 
    $term->bind_event( key => sub {
       $weakself or return;
-      my ( $term, $ev, $args ) = @_;
-      Tickit::Debug->log( Ik => "Key event %s %s (mod=%d)", @{$args}{qw( type str mod )} ) if DEBUG;
-      $weakself->on_key( $args );
+      my ( $term, $ev, $info ) = @_;
+      Tickit::Debug->log( Ik => "Key event %s %s (mod=%d)",
+         map { $info->$_ } qw( type str mod ) ) if DEBUG;
+      $weakself->on_key( $info );
 
       return 1;
    } );
 
    $term->bind_event( mouse => sub {
       $weakself or return;
-      my ( $term, $ev, $args ) = @_;
-      Tickit::Debug->log( Im => "Mouse event %s => %s @%d,%d (mod=%d)", @{$args}{qw( type button col line mod )} ) if DEBUG;
-      $weakself->on_mouse( $args );
+      my ( $term, $ev, $info ) = @_;
+      Tickit::Debug->log( Im => "Mouse event %s => %s @%d,%d (mod=%d)",
+         map { $info->$_ } qw( type button col line mod ) ) if DEBUG;
+      $weakself->on_mouse( $info );
 
       return 1;
    } );
@@ -303,11 +305,11 @@ sub _SIGWINCH
 sub on_key
 {
    my $self = shift;
-   my ( $args ) = @_;
+   my ( $info ) = @_;
 
-   my $str = $args->{str};
+   my $str = $info->str;
 
-   $self->rootwin->_handle_key( $args ) and return;
+   $self->rootwin->_handle_key( $info ) and return;
 
    if( exists $self->{key_binds}{$str} ) {
       $self->{key_binds}{$str}->( $self, $str ) and return;
@@ -349,54 +351,50 @@ sub bind_key
 sub on_mouse
 {
    my $self = shift;
-   my ( $args ) = @_;
+   my ( $info ) = @_;
 
-   my $type = $args->{type};
+   my $type = $info->type;
    if( $type eq "press" ) {
       # Save the mouse press location in case of drag
-      $self->{mouse_last_press} = [ $args->{button}, $args->{line}, $args->{col} ];
+      $self->{mouse_last_press} = [ $info->button, $info->line, $info->col ];
    }
    elsif( $type eq "drag" and !$self->{mouse_dragging} ) {
-      my $start_args = { %$args,
-         type => "drag_start",
-         line => $self->{mouse_last_press}[1],
-         col  => $self->{mouse_last_press}[2],
-      };
+      my $start_info = Tickit::Event::Mouse->_new(
+         drag_start => $info->button, @{$self->{mouse_last_press}}[1,2], $info->mod,
+      );
 
-      my $win = $self->rootwin->_handle_mouse( $start_args );
+      my $win = $self->rootwin->_handle_mouse( $start_info );
       $self->{drag_source_window} = $win;
 
       $self->{mouse_dragging} = 1;
    }
    elsif( $type eq "release" and $self->{mouse_dragging} ) {
-      my $drop_args = { %$args,
-         type => "drag_drop",
-      };
+      my $drop_info = Tickit::Event::Mouse->_new(
+         drag_drop => $info->button, $info->line, $info->col, $info->mod,
+      );
 
-      $self->rootwin->_handle_mouse( $drop_args );
+      $self->rootwin->_handle_mouse( $drop_info );
 
       if( my $win = $self->{drag_source_window} ) {
-         $win->_handle_mouse( { %$args,
-            type => "drag_stop",
-            line => $args->{line} - $win->abs_top,
-            col  => $args->{col}  - $win->abs_left,
-         } );
+         my $stop_info = Tickit::Event::Mouse->_new(
+            drag_stop => $info->button, $info->line - $win->abs_top, $info->col - $win->abs_left, $info->mod,
+         );
+         $win->_handle_mouse( $stop_info );
       }
 
       $self->{mouse_dragging} = 0;
    }
 
-   my $win = $self->rootwin->_handle_mouse( $args );
+   my $win = $self->rootwin->_handle_mouse( $info );
 
    my $srcwin;
    if( $type eq "drag" and
        $srcwin = $self->{drag_source_window} and
        !$win || ( $win && $win != $srcwin ) ) {
-      $srcwin->_handle_mouse( { %$args,
-         type => "drag_outside",
-         line => $args->{line} - $srcwin->abs_top,
-         col  => $args->{col}  - $srcwin->abs_left,
-      } );
+      my $outside_info = Tickit::Event::Mouse->_new(
+         drag_outside => $info->button, $info->line - $srcwin->abs_top, $info->col - $srcwin->abs_left, $info->mod,
+      );
+      $srcwin->_handle_mouse( $outside_info );
    }
 }
 
