@@ -8,7 +8,7 @@ package Tickit::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 use Carp;
 
@@ -18,13 +18,16 @@ C<Tickit::Event> - event information structures
 
 =head1 DESCRIPTION
 
-When event handlers bound to L<Tickit::Term> instances are invoked they
-receive an object instance to contain information about the event. Details of
-the event can be accessed as via accessor methods on these instances.
+When event handlers bound to L<Tickit::Term> or L<Tickit::Window> instances
+are invoked they receive an object instance to contain information about the
+event. Details of the event can be accessed as via accessor methods on these
+instances.
 
-For back-compatibility, each event type also provides a hash reference
-overload method that yields a hash containing keys named after the accessors.
-This code will be removed in a later version as per deprecation policy.
+For back-compatibility, each event type that C<Tickit::Term> can emit also
+provides a hash reference overload method that yields a hash containing keys
+named after the accessors. This code will be removed in a later version as per
+deprecation policy. Existing widget code should be changed to use the new
+object methods rather than the now-legacy hash keys.
 
 =head1 ACCESSORS
 
@@ -46,6 +49,40 @@ sub mod_is_alt   { shift->mod & Tickit::Term::MOD_ALT }
 sub mod_is_ctrl  { shift->mod & Tickit::Term::MOD_CTRL }
 sub mod_is_shift { shift->mod & Tickit::Term::MOD_SHIFT }
 
+package
+   Tickit::Event::Expose;
+our @ISA = qw( Tickit::Event );
+
+=head1 Tickit::Event::Expose
+
+=head2 rb
+
+The L<Tickit::RenderBuffer> instance containing the buffer for this redraw
+cycle.
+
+=head2 rect
+
+A L<Tickit::Rect> instance containing the region of the window that needs
+repainting.
+
+=cut
+
+package
+   Tickit::Event::Focus;
+our @ISA = qw( Tickit::Event );
+
+=head1 Tickit::Event::Focus
+
+=head2 type
+
+An integer giving the focus direction; C<1> for in, C<0> for out.
+
+=head2 win
+
+The child L<Tickit::Window> instance for child-focus notify events.
+
+=cut
+
 package
    Tickit::Event::Key;
 our @ISA = qw( Tickit::Event );
