@@ -8,7 +8,7 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 use Carp;
 
@@ -190,14 +190,15 @@ Flushes the output buffer to the terminal
 
 Installs a new event handler to watch for the event specified by C<$ev>,
 invoking the C<$code> reference when it occurs. C<$code> will be invoked with
-the given terminal, the event name, a C<HASH> reference containing event
-arguments, and the C<$data> value. It returns an ID value that may be used to
-remove the handler by calling C<unbind_event_id>.
+the given terminal, the event name, an event information object, and the
+C<$data> value it was installed with. C<bind_event> returns an ID value that
+may be used to remove the handler by calling C<unbind_event_id>.
 
  $ret = $code->( $term, $ev, $info, $data )
 
-C<$info> will be an instance of some class of L<Tickit::Event> depending on
-the event type.
+The type of C<$info> will depend on the kind of event that was received, as
+indicated by C<$ev>. The information structure types are documented in
+L<Tickit::Event>.
 
 =head2 bind_event (with flags)
 
@@ -232,7 +233,14 @@ sub bind_event
    my $ev = shift;
    my ( $flags, $code, $data ) = ( ref $_[0] ) ? ( 0, @_ ) : @_;
 
-   $self->bind_event_with_flags( $ev, $flags, $code, $data );
+   $self->_bind_event( $ev, $flags, $code, $data );
+}
+
+sub bind_event_with_flags
+{
+   my $self = shift;
+   warnings::warnif( deprecated => "\term->bind_event_with_flags is deprecated; use ->bind_event" );
+   $self->_bind_event( @_ );
 }
 
 sub set_on_resize
