@@ -8,7 +8,7 @@ package Tickit::Test;
 use strict;
 use warnings;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 use Carp;
 
@@ -249,11 +249,7 @@ sub presskey
 {
    my ( $type, $str, $mod ) = @_;
 
-   $tickit->on_key( {
-      type => $type,
-      str  => $str,
-      mod  => $mod||0,
-   } );
+   $tickit->on_key( Tickit::Event::Key->_new( $type, $str, $mod || 0 ) );
 }
 
 =head2 pressmouse
@@ -268,13 +264,7 @@ sub pressmouse
 {
    my ( $ev, $button, $line, $col, $mod ) = @_;
 
-   $tickit->on_mouse( {
-      type   => $ev,
-      button => $button,
-      line   => $line,
-      col    => $col,
-      mod    => $mod||0,
-   } );
+   $tickit->on_mouse( Tickit::Event::Mouse->_new( $ev, $button, $line, $col, $mod || 0 ) );
 }
 
 =head1 TEST FUNCTIONS
