@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use 5.010; # //
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 use Carp;
 
@@ -114,9 +114,10 @@ sub new
    weaken( my $weakself = $self );
    $self->{bind_resize_id} = $term->bind_event( resize => sub {
       $weakself or return;
-      my ( $term, $ev, $args ) = @_;
-      Tickit::Debug->log( Ir => "Resize to $args->{cols}x$args->{lines}" ) if DEBUG;
-      $weakself->resize( $args->{lines}, $args->{cols} );
+      my ( $term, $ev, $info ) = @_;
+      Tickit::Debug->log( Ir => "Resize to %dx%d",
+         map { $info->$_ } qw( cols lines ) ) if DEBUG;
+      $weakself->resize( $info->lines, $info->cols );
 
       return 1;
    } );
@@ -430,6 +431,10 @@ may be used to remove the handler by calling C<unbind_event_id>.
 
  $ret = $code->( $win, $ev, $info, $data )
 
+The type of C<$info> will depend on the kind of event that was received, as
+indicated by C<$ev>. The information structure types are documented in
+L<Tickit::Event>.
+
 This method is preferred over the legacy C<set_on_EVENT> handler methods.
 
 =head2 bind_event (with flags)
@@ -802,6 +807,8 @@ sub set_on_geom_changed
    my $self = shift;
    my ( $code ) = @_;
 
+   warnings::warnif( deprecated => "\$win->set_on_geom_changed is deprecated; use ->bind_event" );
+
    $self->unbind_event_id( delete $self->{event_ids}{geomchange} ) if $self->{event_ids}{geomchange};
    $self->{event_ids}{geomchange} = $self->bind_event( geomchange => sub {
       my ( $self ) = @_;
@@ -859,6 +866,8 @@ sub set_on_key
       shift;
    }
 
+   warnings::warnif( deprecated => "\$win->set_on_key is deprecated; use ->bind_event" );
+
    my ( $code ) = @_;
 
    $self->unbind_event_id( delete $self->{event_ids}{key} ) if $self->{event_ids}{key};
@@ -871,31 +880,30 @@ sub set_on_key
 sub _handle_key
 {
    my $self = shift;
-   my ( $args ) = @_;
+   my ( $info ) = @_;
 
    return 0 unless $self->is_visible;
 
    $self->_reap_dead_children;
    my $children = $self->{child_windows};
    if( $children and @$children and $children->[0]->{steal_input} ) {
-      $children->[0]->_handle_key( $args ) and return 1;
+      $children->[0]->_handle_key( $info ) and return 1;
    }
 
    my $focused_child = $self->{focused_child};
 
    if( $focused_child ) {
-      $focused_child->_handle_key( $args ) and return 1;
+      $focused_child->_handle_key( $info ) and return 1;
    }
 
-   my $event = Tickit::Window::Event->new( %$args );
-   $self->_fire_event( key => $event ) and return 1;
+   $self->_fire_event( key => $info ) and return 1;
 
    if( $children ) {
       foreach my $child ( @$children ) {
          next unless $child; # weakrefs; may be undef
          next if $focused_child and $child == $focused_child;
 
-         $child->_handle_key( $args ) and return 1;
+         $child->_handle_key( $info ) and return 1;
       }
    }
 
@@ -986,6 +994,8 @@ sub set_on_mouse
       shift;
    }
 
+   warnings::warnif( deprecated => "\$win->set_on_mouse is deprecated; use ->bind_event" );
+
    my ( $code ) = @_;
 
    $self->unbind_event_id( delete $self->{event_ids}{mouse} ) if $self->{event_ids}{mouse};
@@ -998,12 +1008,12 @@ sub set_on_mouse
 sub _handle_mouse
 {
    my $self = shift;
-   my ( $args ) = @_;
+   my ( $info ) = @_;
 
    return unless $self->is_visible;
 
-   my $line = $args->{line};
-   my $col  = $args->{col};
+   my $line = $info->line;
+   my $col  = $info->col;
 
    if( my $children = $self->{child_windows} ) {
       foreach my $child ( @$children ) {
@@ -1017,19 +1027,16 @@ sub _handle_mouse
             next if $child_col  < 0 or $child_col  >= $child->cols;
          }
 
-         my $childargs = {
-            %$args,
-            line => $child_line,
-            col  => $child_col,
-         };
+         my $child_info = Tickit::Event::Mouse->_new(
+            $info->type, $info->button, $info->line - $child->top, $info->col - $child->left, $info->mod,
+         );
 
-         my $ret = $child->_handle_mouse( $childargs );
+         my $ret = $child->_handle_mouse( $child_info );
          return $ret if $ret;
       }
    }
 
-   my $event = Tickit::Window::Event->new( %$args );
-   $self->_fire_event( mouse => $event ) and return $self;
+   $self->_fire_event( mouse => $info ) and return $self;
 
    return 0;
 }
@@ -1068,6 +1075,8 @@ sub set_on_expose
       shift;
    }
 
+   warnings::warnif( deprecated => "\$win->set_on_expose is deprecated; use ->bind_event" );
+
    my ( $code ) = @_;
 
    $self->unbind_event_id( delete $self->{event_ids}{expose} ) if $self->{event_ids}{expose};
@@ -1106,7 +1115,7 @@ sub _do_expose
 
    $rb->save;
 
-   $self->_fire_event( expose => Tickit::Window::Event->new( rb => $rb, rect => $rect ) );
+   $self->_fire_event( expose => Tickit::Event::Expose->_new( $rb, $rect ) );
 
    $rb->restore;
 }
@@ -1192,6 +1201,8 @@ sub set_on_focus
    my $self = shift;
    my ( $code ) = @_;
 
+   warnings::warnif( deprecated => "\$win->set_on_focus is deprecated; use ->bind_event" );
+
    $self->unbind_event_id( delete $self->{event_ids}{focus} ) if $self->{event_ids}{focus};
    $self->{event_ids}{focus} = $self->bind_event( focus => sub {
       my ( $self, undef, $info ) = @_;
@@ -1841,10 +1852,10 @@ sub _focus_gained
 
    if( !$child ) {
       $self->{focused} = 1;
-      $self->_fire_event( focus => Tickit::Window::Event->new( type => 1, win => undef ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( 1, undef ) );
    }
    elsif( $self->{focus_child_notify} ) {
-      $self->_fire_event( focus => Tickit::Window::Event->new( type => 1, win => $child ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( 1, $child ) );
    }
 
    $self->{focused_child} = $child;
@@ -1857,12 +1868,12 @@ sub _focus_lost
 
    if( my $focused_child = $self->{focused_child} ) {
       $focused_child->_focus_lost;
-      $self->_fire_event( focus => Tickit::Window::Event->new( type => 0, win => $focused_child ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( 0, $focused_child ) );
    }
 
    if( $self->{focused} ) {
       undef $self->{focused};
-      $self->_fire_event( focus => Tickit::Window::Event->new( type => 0, win => undef ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( 0, undef ) );
    }
 }
 
@@ -1994,85 +2005,6 @@ use overload
    bool => sub { 1 },
    fallback => 1;
 
-package # hide from indexer
-   Tickit::Window::Event;
-
-=head1 EVENT STRUCTURE
-
-Objects in this class are passed to C<bind_event> handlers, to give details of
-the event that happened.
-
-=head2 $info->type
-
-A string giving the event type name. The valid values here will differ
-depending on whether it is a keyboard, mouse or focus event.
-
-=head2 $info->str
-
-A string representing the base key and its modifiers. Modifiers are given as
-an optional prefix; any of C<M-> for Alt (Meta), C<C-> for Control, or C<S->
-for Shift (in that order), followed by the base key. For UTF-8 text this will
-be a single character. For non-Unicode special keys this will be the name of
-the key.
-
-=head2 $info->line
-
-=head2 $info->col
-
-The position for mouse events, 0-based.
-
-=head2 $info->button
-
-The button number for non-wheel mouse events, or the mouse wheel direction as
-a string (one fo C<up> or C<down>). Note that for C<release> type events, the
-mouse button may not be reliable; not all terminals can report it.
-
-=head2 $info->mod
-
-A bitmask of modifier state. Valid for both keyboard and mouse events.
-
-=head2 $info->rb
-
-The window's L<Tickit::RenderBuffer> instance for expose events.
-
-=head2 $info->rect
-
-The exposed L<Tickit::Rect> for expose events.
-
-=head2 $info->win
-
-The child window, if any, for focus events.
-
-=cut
-
-use Carp;
-
-sub new
-{
-   my $class = shift;
-   bless { @_ }, $class;
-}
-
-foreach my $key (qw( type str mod button line col rect rb win )) {
-   no strict 'refs';
-   *$key = sub { exists $_[0]{$key} ? $_[0]{$key} : croak "Event has no '$key' field" }
-}
-
-=head2 $info->mod_is_alt
-
-=head2 $info->mod_is_ctrl
-
-=head2 $info->mod_is_shift
-
-Convenient shortcuts to tests on the C<mod> bitmask to test if each of the
-modifiers is set.
-
-=cut
-
-sub mod_is_alt   { shift->mod & Tickit::Term::MOD_ALT }
-sub mod_is_ctrl  { shift->mod & Tickit::Term::MOD_CTRL }
-sub mod_is_shift { shift->mod & Tickit::Term::MOD_SHIFT }
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
