@@ -72,6 +72,7 @@ struct TickitTerm {
   int colors;
   TickitPen *pen;
 
+  int refcount;
   struct TickitEventHook *hooks;
 };
 
@@ -106,8 +107,6 @@ TickitTerm *tickit_term_new(void)
   return tickit_term_new_for_termtype(termtype);
 }
 
-void tickit_term_free(TickitTerm *tt);
-
 TickitTerm *tickit_term_new_for_termtype(const char *termtype)
 {
   for(int i = 0; driver_probes[i]; i++) {
@@ -157,6 +156,7 @@ TickitTerm *tickit_term_new_for_driver(TickitTermDriver *ttd)
   tt->next_sigwinch_observer = NULL;
   tt->window_changed = false;
 
+  tt->refcount = 1;
   tt->hooks = NULL;
 
   /* Initially empty because we don't necessarily know the initial state
@@ -193,7 +193,7 @@ TickitTerm *tickit_term_open_stdio(void)
   return tt;
 }
 
-void tickit_term_free(TickitTerm *tt)
+void tickit_term_destroy(TickitTerm *tt)
 {
   if(tt->observe_winch)
     tickit_term_observe_sigwinch(tt, false);
@@ -228,9 +228,17 @@ void tickit_term_free(TickitTerm *tt)
   free(tt);
 }
 
-void tickit_term_destroy(TickitTerm *tt)
+TickitTerm *tickit_term_ref(TickitTerm *tt)
 {
-  tickit_term_free(tt);
+  tt->refcount++;
+  return tt;
+}
+
+void tickit_term_unref(TickitTerm *tt)
+{
+  tt->refcount--;
+  if(!tt->refcount)
+    tickit_term_destroy(tt);
 }
 
 const char *tickit_term_get_termtype(TickitTerm *tt)
