@@ -36,6 +36,7 @@ struct TickitWindow {
   bool steal_input;
   bool focus_child_notify;
 
+  int refcount;
   struct TickitEventHook *hooks;
 };
 
@@ -215,6 +216,7 @@ static void init_window(TickitWindow *win, TickitWindow *parent, TickitRect rect
   win->steal_input = false;
   win->focus_child_notify = false;
 
+  win->refcount = 1;
   win->hooks = NULL;
 }
 
@@ -229,7 +231,7 @@ TickitWindow* tickit_window_new_root(TickitTerm *term)
 
   init_window(ROOT_AS_WINDOW(root), NULL, (TickitRect) { .top = 0, .left = 0, .lines = lines, .cols = cols });
 
-  root->term = term;
+  root->term = tickit_term_ref(term);
   root->hierarchy_changes = NULL;
   root->needs_expose = false;
   root->needs_restore = false;
@@ -325,11 +327,26 @@ void tickit_window_destroy(TickitWindow *win)
     }
 
     tickit_term_unbind_event_id(root->term, root->event_id);
+
+    tickit_term_unref(root->term);
   }
 
   free(win);
 }
 
+TickitWindow *tickit_window_ref(TickitWindow *win)
+{
+  win->refcount++;
+  return win;
+}
+
+void tickit_window_unref(TickitWindow *win)
+{
+  win->refcount--;
+  if(!win->refcount)
+    tickit_window_destroy(win);
+}
+
 void tickit_window_raise(TickitWindow *win)
 {
   _request_hierarchy_change(TICKIT_HIERARCHY_RAISE, win);
@@ -672,7 +689,7 @@ void tickit_window_flush(TickitWindow *win)
     free(rects);
 
     tickit_renderbuffer_flush_to_term(rb, root->term);
-    tickit_renderbuffer_destroy(rb);
+    tickit_renderbuffer_unref(rb);
 
     root->needs_restore = true;
   }
